<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */


// Save searchMask state on switch
if ($searchMaskState = $App->getParam('searchMaskState')) {
    $App->setSession('searchMaskState',$searchMaskState);
    if ($searchMaskState == 'Simple') {
        $App->setSession('SimpleQuery',new Query('empty'));
    }
    if ($searchMaskState == 'Ext') {
        $App->setSession('ExtQuery',new Query('empty'));
    }
    if ($searchMaskState == 'Konv') {
        $App->setSession('ExtQuery',new Query('empty'));
    }

}

// Save storedSearch list
if ($storedSearchState = $App->getParam('storedSearchState')) {
    $App->setSession('storedSearchState',$storedSearchState);
}
eor();

?>
